/// <reference types="react" />
import * as typeIs from './typeIs';
/**
 * Utility for making it easier to couple a React Component to a css selector.
 * Useful when writing css selectors that rely on interactivity, i.e. :hover.
 * Example:
 *  const checkBoxWrapper = createDataProp('checkbox-wrapper');
 *  // Used as selector:
 *  css`&:hover ${checkboxWrapper.selector} { }`
 *  // Used on React Component
 *  <div {...checkboxWrapper.prop} />
 * @param {string} name Name of element we want to reference.
 */
export declare function createDataProp(name: string): {
    prop: {
        [x: string]: string;
    };
    selector: string;
};
/** Helper type to extract an HTML element's valid props */
export declare type HTMLElementProps<Element extends keyof JSX.IntrinsicElements> = JSX.IntrinsicElements[Element] extends React.DetailedHTMLProps<infer Props, any> ? Props : never;
export { typeIs };
/** Helper type to check if element is a specific React Component  */
export declare function isComponentType<T = React.ReactElement>(element: React.ReactNode, displayName: string): element is T;
/** Object mapping keyCodes to keys */
export declare const keyMap: {
    ArrowUp: number;
    ArrowDown: number;
    ArrowLeft: number;
    ArrowRight: number;
    Enter: number;
    Escape: number;
    Space: number;
    Tab: number;
};
/**
 * An enum of accepted values for the "aria-current" attribute, used for
 * indicating current/active state across several contexts.
 *
 * The values "false", the empty string, and an ommission of this attribute
 * are all treated identically by user agents and screen readers.
 *
 * W3C Recommendation: https://www.w3.org/TR/wai-aria-1.1/#aria-current
 */
export declare const AriaCurrentValue: {
    readonly Page: "page";
    readonly Step: "step";
    readonly Location: "location";
    readonly Date: "date";
    readonly Time: "time";
    readonly True: "true";
    readonly Unset: "false";
};
export declare type AriaCurrentValue = typeof AriaCurrentValue[keyof typeof AriaCurrentValue];
